@@ -15,17 +15,19 @@
  *  Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "fileformatmanager.h"
 #include "fileformatinterface.h"
 #include "logging_p.h"
 
+#include <KPluginFactory>
 #include <KPluginLoader>
 #include <KPluginMetaData>
-#include <KServiceTypeTrader>
 #include <KLocalizedString>
+
+#include <QCoreApplication>
 #include <QString>
 #include <QDir>
 #include <QDirIterator>
@@ -101,28 +103,26 @@ void FileFormatManager::loadBackends()
     }
     d->backends.clear();
 
-    // dirs to check for plugins
-    QStringList dirsToCheck;
-    foreach (const QString &directory, QCoreApplication::libraryPaths()) {
-        dirsToCheck << directory + QDir::separator() + "rocs/fileformats";
-    }
-
-    // load plugins
-    QPluginLoader loader;
-    foreach (const QString &dir, dirsToCheck) {
-        QVector<KPluginMetaData> metadataList = KPluginLoader::findPlugins(dir,[=](const KPluginMetaData &data){
+    QVector<KPluginMetaData> metadataList = KPluginLoader::findPlugins(
+        "rocs/fileformats",
+        [](const KPluginMetaData &data){
             return data.serviceTypes().contains("rocs/graphtheory/fileformat");
-        });
-        for (const auto &metadata : metadataList) {
-            loader.setFileName(metadata.fileName());
-            qCDebug(GRAPHTHEORY_FILEFORMAT) << "Load Plugin: " << metadata.name();
-            if (!loader.load()) {
-                qCCritical(GRAPHTHEORY_FILEFORMAT) << "Error while loading plugin: " << metadata.name();
-            }
-            KPluginFactory *factory = KPluginLoader(loader.fileName()).factory();
-            FileFormatInterface *plugin = factory->create<FileFormatInterface>(this);
-            d->backends.append(plugin);
         }
+    );
+
+    QPluginLoader loader;
+
+    foreach (const auto &metadata, metadataList) {
+        loader.setFileName(metadata.fileName());
+
+        qCDebug(GRAPHTHEORY_FILEFORMAT) << "Load Plugin: " << metadata.name();
+        if (!loader.load()) {
+            qCCritical(GRAPHTHEORY_FILEFORMAT) << "Error while loading plugin: " << metadata.name();
+        }
+
+        KPluginFactory *factory = KPluginLoader(loader.fileName()).factory();
+        FileFormatInterface *plugin = factory->create<FileFormatInterface>(this);
+        d->backends.append(plugin);
     }
 
     // display a QMessageBox if no plugins are found
@@ -131,8 +131,8 @@ void FileFormatManager::loadBackends()
         pluginErrorMessageBox.setWindowTitle(i18n("Plugin Error"));
         pluginErrorMessageBox.setTextFormat(Qt::RichText);
         pluginErrorMessageBox.setText(i18n("Plugins could not be found in specified directories:<br>")+
-                                         dirsToCheck.join("<br>")+
-                                         i18n("<br><br> Check <a href='http://doc.qt.io/qt-5/deployment-plugins.html'>"
+                                         QCoreApplication::libraryPaths().join("/rocs/fileformats<br>")+
+                                         i18n("<br><br> Check <a href='https://doc.qt.io/qt-5/deployment-plugins.html'>"
                                          "this link</a> for further information."));
         pluginErrorMessageBox.setDefaultButton(QMessageBox::Close);
         pluginErrorMessageBox.exec();
